@@ -1,6 +1,8 @@
-
 package Zonemaster::LDNS::RR::NID;
 
+use strict;
+use warnings;
+
 use parent 'Zonemaster::LDNS::RR';
 
 1;
